@@ -245,7 +245,7 @@
 ;; V1.62 20Aug2002 Peter S Galbraith <psg@debian.org>
 ;; V1.63 05Sep2002 Peter S Galbraith <psg@debian.org>
 ;;    Fontify bugs on multiple-line closes: statements.  Patch from
-;;    Frdric Bothamy.  (Closes: #159041)
+;;    Frédéric Bothamy.  (Closes: #159041)
 ;; V1.64 05Sep2002 Peter S Galbraith <psg@debian.org>
 ;;    debian-changelog-suggest-version fix (Closes: #159643)
 ;; V1.65 05Sep2002 Peter S Galbraith <psg@debian.org>
@@ -347,7 +347,7 @@
 ;;    Simplify auto-mode-alist (Closes: #587924)
 ;; V1.95 01Dec2013 Matt Kraai <kraai@debian.org>
 ;;    Change the default urgency to medium (Closes: #731105)
-;; V1.96 06Nov2016 Guido Gnther <agx@sigxcpu.org>
+;; V1.96 06Nov2016 Guido Günther <agx@sigxcpu.org>
 ;;  Bug fix: "improve handling of {old-, }stable-proposed-updates", thanks
 ;;    to Guido Gunther (Closes: #818010).
 ;; V1.97 06Nov2016 Pierre Carrier (on 2013-07-04)
@@ -441,6 +441,12 @@ This defaults to the value of (in order of precedence):
     "focal"
     "groovy"
     "hirsute"
+    "impish"
+    "jammy"
+    "kinetic"
+    "lunar"
+    "mantic"
+    "noble"
     "UNRELEASED" )
   "*Allowed values for distribution."
   :group 'debian-changelog
@@ -526,7 +532,7 @@ Pass ARGS to `replace-regexp-in-string' (GNU Emacs) or to
 (require 'add-log)
 (require 'easymenu)
 (eval-when-compile
-  (require 'cl))
+  (require 'cl-lib))
 
 ;; XEmacs21.1 compatibility -- from XEmacs's apel/poe.el
 (unless (fboundp 'match-string-no-properties)
@@ -1305,7 +1311,7 @@ a list in the form (NAME EMAIL)."
 the form [ NAME ]."
   (goto-char (point-min))
   (re-search-forward (concat "\n " separator))
-  (previous-line 1)
+  (forward-line -1)
   (insert "\n  [ " name " ]")
   (when (string= "--" separator)
     (insert "\n")))
@@ -1488,7 +1494,7 @@ interface to set it, or simply set the variable
    '(debian-changelog-fontify-frozen . font-lock-type-face)
    '(debian-changelog-fontify-unstable . font-lock-string-face)
    '(debian-changelog-fontify-experimental . debian-changelog-warning-face)
-   '(debian-changelog-fontify-hirsute . debian-changelog-warning-face)
+   '(debian-changelog-fontify-noble . debian-changelog-warning-face)
    '(debian-changelog-fontify-unreleased . debian-changelog-warning-face)
    '(debian-changelog-fontify-urgency-crit . debian-changelog-warning-face)
    '(debian-changelog-fontify-urgency-high . debian-changelog-warning-face)
@@ -1621,8 +1627,8 @@ match 1 -> package name
      (list (match-beginning 1)(match-end 1)))
     t))
 
-(defun debian-changelog-fontify-hirsute (limit)
-  (when (re-search-forward "^\\sw.* (.+).* \\(hirsute\\)" limit t)
+(defun debian-changelog-fontify-noble (limit)
+  (when (re-search-forward "^\\sw.* (.+).* \\(noble\\)" limit t)
     (store-match-data
      (list (match-beginning 1)(match-end 1)))
     t))
@@ -1733,7 +1739,7 @@ Also set keymap."
 ;;; imenu stuff - Peter Galbraith, May 2001
 
 (eval-when-compile
-  (require 'cl)
+  (require 'cl-lib)
   (if (fboundp 'imenu)                    ;Make sure auto-load is loaded
       (require 'imenu)))
 
@@ -1790,11 +1796,9 @@ Also set keymap."
               )
           (setq debian-changelog-imenu-counter -99)
           (goto-char (point-max))
-          (imenu-progress-message prev-pos 0 t)
 ;;;          (message "Scanning changelog history...")
           (setq debian-changelog-imenu-doing-closebug nil)
           (while (debian-changelog-imenu-prev-index-position-function)
-            (imenu-progress-message prev-pos nil t)
             (let ((marker (make-marker)))
               (set-marker marker (point))
               (cond
@@ -1804,7 +1808,6 @@ Also set keymap."
                ((match-beginning 4)     ;version number
                 (push (cons (match-string-no-properties 4) marker)
                       index-alist)))))
-          (imenu-progress-message prev-pos 100 t)
 ;;;       (message "Scanning changelog history... done.")
           (cond
            (index-bug-alist
